%lcr
% Function which loads V0 and VC amplitude and phase information vs
% frequency for the LCR experiment. Experimental data is overlaid upon
% theoretical predictions.
%
% LAST UPDATED by Andy French May 2017

function lcr

%Define capacitance /F
C = 0.07*1e-6;

%Define inductance /H
L = 1.0;

%Define resistance /Ohms
R = 380;

%Max frequency for model
fmax = 2000;

%Number of data points for model
N = 1000;

%Fontsize for graphs
fsize = 18;

%

%Load Excel data file
[filename, pathname, filterindex] = ...
    uigetfile({'*.xlsx';'*.xls'}, 'Choose Excel file');
if filename==0
    return
else
   [num,txt,raw] = xlsread([pathname,filename]); 
end

%Assign columns of data

%Frequency in Hz
fdata = num(:,1);

%V0 amplitude /volts
V0 = num(:,2);

%VC amplitude /volts
VC = num(:,3);

%Phase difference between VC and V0 /degrees
phase_deg = num(:,4);

%%

%LCR model
f = linspace(0,fmax,N);
w = 2*pi*f;
ZC = 1./(1i*w*C);
ZL = 1i*w*L;
ZR = R;
VC_by_V0 = ZC./(ZC+ZL+ZR);

%Plot model amplitude and overlay with experimental data
plot( f, abs(VC_by_V0),'b',fdata,VC./V0,'r+' );
xlabel('frequency /Hz','fontsize',fsize);
ylabel('V_C/V_0','fontsize',fsize);
title(['Amplitude ratio V_C/V_0 L = ',num2str(L,2),', C = ',...
    num2str(C*1e6,2),'\mu','F, R = ',num2str(R,4),'\Omega'],...
    'fontsize',fsize)
grid on
box on
set(gca,'fontsize',fsize)
print(gcf,'amplitude ratio.png','-dpng','-r300');
clf;

%Plot model phase and overlay with experimental data
plot( f, -(180/pi)*angle(VC_by_V0),'b',fdata,phase_deg,'r+' );
xlabel('frequency /Hz','fontsize',fsize);
ylabel('phase /deg','fontsize',fsize);
title(['Phase difference /deg L = ',num2str(L,2),', C = ',...
    num2str(C*1e6,2),'\mu','F, R = ',num2str(R,4),'\Omega'],...
    'fontsize',fsize)
grid on
box on
set(gca,'fontsize',fsize)
print(gcf,'phase.png','-dpng','-r300');
close(gcf);

%End of code